@@ -3,7 +3,7 @@ package Specio::Constraint::Role::IsaType;
 use strict;
 use warnings;
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 use Storable qw( dclone );
 
@@ -41,16 +41,18 @@ sub _wrap_message_generator {
 
     my $class = $self->class;
 
-    $generator //= sub {
-        my $description = shift;
-        my $value       = shift;
+    unless ( defined $generator ) {
+        $generator = sub {
+            my $description = shift;
+            my $value       = shift;
 
-        return
-              "Validation failed for $description with value "
-            . Devel::PartialDump->new->dump($value)
-            . '(not isa '
-            . $class . ')';
-    };
+            return
+                  "Validation failed for $description with value "
+                . Devel::PartialDump->new->dump($value)
+                . '(not isa '
+                . $class . ')';
+        };
+    }
 
     my $d = $self->_description;
 
@@ -74,7 +76,7 @@ Specio::Constraint::Role::IsaType - Provides a common implementation for Specio:
 
 =head1 VERSION
 
-version 0.17
+version 0.18
 
 =head1 DESCRIPTION
 
